﻿using System.Linq;
using System.Windows;
using ThinkGeo.Core;


namespace LegendTest
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void WpfMap_Loaded(object sender, RoutedEventArgs e)
        {
            wpfMap1.MapUnit = GeographyUnit.Meter;

            LegendAdornmentLayer layer = new LegendAdornmentLayer();
            layer.Width = 150;
            layer.Location = AdornmentLocation.LowerLeft;

            layer.LegendItems.Add(new LegendItem()
            {
                ImageStyle = new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(170, GeoColors.Green))),
                TextStyle = new TextStyle("long description .......................", new GeoFont("Arial", 20), new GeoSolidBrush(GeoColors.Black))
            });

            var legendPrinterLayer = new LegendPrinterLayer(layer)
            {
                BackgroundMask = new AreaStyle(new GeoPen(GeoColors.Black, 1), new GeoSolidBrush(new GeoColor(255, 230, 230, 230)))
            
            //GeoColor(255, 230, 230, 230),
            //              GeoColors.Black, 1),
            };
            

            double bordWidth = PrinterHelper.ConvertLength(CalculateLegendWidth(layer), PrintingUnit.Point, PrintingUnit.Inch);

            legendPrinterLayer.SetPosition(bordWidth + 0.6, 1, -2.9, 3.9, PrintingUnit.Inch);
            
            wpfMap1.InteractiveOverlays.Add("PrintPreviewOverlay", new PrinterInteractiveOverlay());
            var printerInteractiveOverlay = (PrinterInteractiveOverlay)wpfMap1.InteractiveOverlays["PrintPreviewOverlay"];

            


            printerInteractiveOverlay.PrinterLayers.Add("LegendPrinterLayer", legendPrinterLayer);

            legendPrinterLayer.Open();
            wpfMap1.CurrentExtent = legendPrinterLayer.GetBoundingBox();
            wpfMap1.Refresh();
        }


        float CalculateLegendWidth(LegendAdornmentLayer layer)
        {
            var textGeoCanvas = new SkiaGeoCanvas();

           
            var result = (float)0;
            var currentValue = (float)0;




            layer.LegendItems.ToList().ForEach(c =>
            {
                currentValue = textGeoCanvas.MeasureText(c.TextStyle.TextColumnName, c.TextStyle.Font).Width;
                if (currentValue > result)
                    result = currentValue;
            });

            return result;
        }
    }
}
